pub struct MechanismAdapter;Expand description
Adapter for mechanism search and lifecycle.
Implementations
Sourceimpl MechanismAdapter
impl MechanismAdapter
Sourcepub fn fit_mechanism(
name: &str,
description: &str,
fit_score: f64,
) -> MechanismBundleV1
pub fn fit_mechanism( name: &str, description: &str, fit_score: f64, ) -> MechanismBundleV1
Fit a candidate mechanism to data.
Sourcepub fn refute_mechanism(
mechanism: &mut MechanismBundleV1,
refuters: Vec<RefuterV1>,
)
pub fn refute_mechanism( mechanism: &mut MechanismBundleV1, refuters: Vec<RefuterV1>, )
Run a refuter suite against a mechanism.
Sourcepub fn supersede_mechanism(
old: &mut MechanismBundleV1,
new_name: &str,
new_description: &str,
new_fit_score: f64,
) -> MechanismBundleV1
pub fn supersede_mechanism( old: &mut MechanismBundleV1, new_name: &str, new_description: &str, new_fit_score: f64, ) -> MechanismBundleV1
Create a new version of a mechanism, superseding the old one.
Sourcepub fn can_promote(mechanism: &MechanismBundleV1) -> bool
pub fn can_promote(mechanism: &MechanismBundleV1) -> bool
Check if a mechanism can be promoted to published.